Elita
-----

Elita is an engine/framework for continuous deployment and API-driven infrastructure utilizing git
and salt. Elita maps build packages to filesystem locations on an arbitrary number of remote servers and allows deployment
(and more) via RESTful HTTP calls.

It uses `salt <http://www.saltstack
.org>`_ remote execution and a plugin architecture to allow custom actions and hook routines.


